<?php
/**
 * @file
 * Common functions for the Drush re-make extension.
 */


/**
 * Implements hook_drush_command().
 */
function drush_remake_drush_command() {
  $items = array();

  $items['remake'] = array(
    'description' => "Re-makes an installation profile using drush make",
    'arguments' => array(
      'installation profile' => dt('The name of the installation profile to re-make'),
    ),
    'options' => array(
      'no-working-copy' => dt('Pass this option in to do the remake without the --working-copy option being passed to drush make'),
    ),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUPAL_ROOT, // Bootstrap into a Drupal root.
    'allow-additional-options' => array(
      'make',
    ),
  );

  return $items;
}

/**
 * Validation hook for the drush_remake command.
 */
function drush_drush_remake_remake_validate() {
  $args = func_get_args();
  if (empty($args)) {
    // Try to offer a choice.
    $options = drush_remake_find_profiles();
    // If we can't offer any choices, return an error.
    if (count($options) == 0) {
      return drush_set_error('DRUSH_REMAKE_INCORRECT_ARGUMENTS', dt("You must specify the installation profile to rebuild."));
    }
    // If there's only once choice then just select it.
    elseif (count($options) == 1) {
      reset($options);
      $profile = key($options);
    }
    // Otherwise give the user a choice.
    else {
      $choice = drush_choice($options, dt('Choose an installation profile to remake:'));
      if (!empty($choice)) {
        $profile = $choice;
      }
      else {
        return drush_set_error('DRUSH_REMAKE_INCORRECT_ARGUMENTS', dt("You must specify the installation profile to rebuild."));
      }
    }
  }
  else {
    // Check that the first argument is actually a valid install profile with a make file.
    $profile = $args[0];
  }


  if (!file_exists(DRUPAL_ROOT . '/profiles/' . $profile)) {
    return drush_set_error('DRUSH_REMAKE_UNKNOWN_PROFILE', dt("Could not find an installation profile."));
  }


  if (!file_exists(DRUPAL_ROOT . '/profiles/' . $profile . '/' . $profile . '.make')) {
    return drush_set_error('DRUSH_REMAKE_NO_MAKE_FILE', dt("Could not find a valid make file."));
  }

  drush_set_context('remake_file', $profile);
}

/**
 * Get installation profiles with a make file.
 */
function drush_remake_find_profiles() {
  $options = array();
  foreach (glob(DRUPAL_ROOT . '/profiles/*') as $profile) {
    if (is_dir($profile)) {
      $basename = basename($profile);
      if (file_exists(DRUPAL_ROOT . '/profiles/' . $basename . '/' . $basename . '.make')) {
        $options[$basename] = $basename;
      }
    }
  }
  return $options;
}
