<?php
/**
 * @file
 * The Drush re-make extension for Drush 4.
 */

require 'drush_remake.common.inc';

/**
 * The main drush remake command callback.
 */
function drush_drush_remake_remake() {
  $profile = drush_get_context('remake_file');
  $directory = DRUPAL_ROOT . '/profiles/' . $profile;

  drush_log(dt('Remaking @profile from @makefile.', array('@profile' => $profile, '@makefile' => $directory . '/' . $profile . '.make')), 'ok');

  // Build the command.
  $args = array();
  $options = array();

  $args[] = $directory . '/' . $profile . '.make';
  $args[] = '.';

  // We cd to run the command, so the contrib destination should be set to: '.'
  $options['contrib-destination'] = '.';

  // People should use drush make to make with a valid Drupal core.
  $options['no-core'] = TRUE;

  // Set the working-copy option by default, but allow people to not send it.
  if (drush_get_option('no-working-copy', FALSE)) {
    $options['working-copy'] = FALSE;
  }
  else {
    $options['working-copy'] = TRUE;
  }

  // Set this magical property to get feedback as the command is running
  $options['#interactive'] = TRUE;

  // Don't run with a Drupal root.
  $options['root'] = NULL;

  // Transparently pass through most other options
  $other_options = drush_get_context('cli');
  unset($other_options['no-working-copy'], $other_options['php']);
  $options += $other_options;

  // Call the command
  drush_remake_drush_cd_and_backend_invoke_args($directory, 'make', $args, $options);
}


/**
 * Execute the given command in the given directory.
 */
function drush_remake_drush_cd_and_backend_invoke_args($directory, $command, $args = array(), $data = NULL, $integrate = TRUE) {

  $cmd = _drush_backend_generate_command($command, $args, $data);

  // Prepend a cd to the correct directory
  $cmd = 'cd ' . drush_escapeshellarg($directory) . ' && ' . $cmd;

  drush_log(dt('Running: !cmd', array('!cmd' => $cmd)), 'command');
  drush_log(dt("executing !cmd", array('!cmd' => $cmd)));
  return drush_op_system($cmd);
}
